@@ -313,6 +313,10 @@ class data(object):
         for row in rows:
             columns[row["transientBucket_column"]] = row["fs_table_column"]
 
+        if "raDeg" not in columns:
+            print(f"No coordinates to match in the {fsTableName} table")
+            return []
+
         # BUILD QUERY TO GET UNIQUE UN-MATCHED SOURCES
         fs_name = columns["name"]
         self.fs_name = fs_name
@@ -365,7 +369,6 @@ class data(object):
             ticker += len(fs_name_list)
             print("Matching %(ticker)s/%(total)s sources in the %(fsTableName)s against the transientBucket table" % locals())
 
-            print(fs_ra_list)
             # CONESEARCH TRANSIENT BUCKET FOR PRE-KNOWN SOURCES FROM OTHER
             # SURVEYS
             from HMpTy.mysql import conesearch
